@@ -76,7 +76,10 @@ class Utilities(script_utilities.Utilities):
         if not obj:
             return False
 
-        attrs = dict([attr.split(':', 1) for attr in obj.getAttributes()])
+        try:
+            attrs = dict([attr.split(':', 1) for attr in obj.getAttributes()])
+        except:
+            return False
         return attrs.get('toolkit', '') == 'WebKitGtk'
 
     def isReadOnlyTextArea(self, obj):
@@ -112,14 +115,14 @@ class Utilities(script_utilities.Utilities):
 
         return text
 
-    def getObjectsFromEOCs(self, obj, boundary=None, offset=None):
+    def getObjectsFromEOCs(self, obj, offset=None, boundary=None):
         """Breaks the string containing a mixture of text and embedded object
         characters into a list of (obj, startOffset, endOffset, string) tuples.
 
         Arguments
         - obj: the object whose EOCs we need to expand into tuples
-        - boundary: the pyatspi text boundary type. If None, get all text.
         - offset: the character offset. If None, use the current offset.
+        - boundary: the pyatspi text boundary type. If None, get all text.
 
         Returns a list of (obj, startOffset, endOffset, string) tuples.
         """
