@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright (C) 2013 Igalia, S.L.
+# Copyright (C) 2013-2014 Igalia, S.L.
 #
 # Author: Joanmarie Diggs <jdiggs@igalia.com>
 #
@@ -22,7 +22,7 @@
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2013 Igalia, S.L."
+__copyright__ = "Copyright (c) 2013-2014 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
@@ -42,6 +42,23 @@ class Script(default.Script):
     def getUtilities(self):
         return Utilities(self)
 
+    def onActiveDescendantChanged(self, event):
+        """Callback for object:active-descendant-changed accessibility events."""
+
+        role = event.source.getRole()
+
+        try:
+            focusedRole = orca_state.locusOfFocus.getRole()
+        except:
+            pass
+        else:
+            # This is very likely typeahead search and not a real focus change.
+            tableRoles = [pyatspi.ROLE_TABLE, pyatspi.ROLE_TREE_TABLE]
+            if focusedRole == pyatspi.ROLE_TEXT and role in tableRoles:
+                orca.setLocusOfFocus(event, event.source, False)
+
+        default.Script.onActiveDescendantChanged(self, event)
+
     def onCheckedChanged(self, event):
         """Callback for object:state-changed:checked accessibility events."""
 
@@ -125,6 +142,20 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, obj)
             return
 
+    def onShowingChanged(self, event):
+        """Callback for object:state-changed:showing accessibility events."""
+
+        obj = event.source
+        if not self.utilities._isNonModalPopOver(obj):
+            default.Script.onShowingChanged(self, event)
+            return
+
+        if event.detail1:
+            speech.speak(self.speechGenerator.generateSpeech(obj))
+            labels = self.utilities.unrelatedLabels(obj)
+            msg = ' '.join(map(self.utilities.displayedText, labels))
+            self.presentMessage(msg)
+
     def onTextSelectionChanged(self, event):
         """Callback for object:text-selection-changed accessibility events."""
 
